@@ -9,22 +9,14 @@ from Products.CMFBibliographyAT.tests import dummy
 # and the types get still registered with the types tool
 from Products.GenericSetup import EXTENSION, profile_registry
 
-profile_registry.registerProfile('test_types',
-    'CMFBibliography member types for testing',
-    "Extension profile including CMFBib's member types for testing",
-    'profiles/testing_member_types',
-    'Products.CMFBibliographyAT',
-    EXTENSION)
-
 ZopeTestCase.installProduct('CMFBibliographyAT')
-PROFILES = ['Products.CMFBibliographyAT:default',
-            'Products.CMFBibliographyAT:test_types',]
+PROFILES = ['Products.CMFBibliographyAT:default']
 PloneTestCase.setupPloneSite(extension_profiles=PROFILES)
 
 
 # This is so we can find our own files
 from Products.CMFBibliographyAT.tests import GLOBALS
-from Globals import package_home
+from App.Common import package_home
 PACKAGE_HOME = package_home(GLOBALS)
 
 from os.path import join
